asr.setup.decorate
==================

.. automodule:: asr.setup.decorate

   
   
   .. rubric:: Functions

   
   .. autofunction:: apply_substitution
   .. autofunction:: find_substitutions
   .. autofunction:: generate_structures
   .. autofunction:: get_p_ab
   
   

   
   
   

   
   
   